@@ -4,6 +4,7 @@ use Mojo::Base 'Mojolicious';
 use Mojo::Collection 'c';
 use Mojo::JSON qw(encode_json);
 use Mojo::Pg;
+use Mojo::URL;
 use SReview;
 use SReview::Config;
 use SReview::Config::Common;
@@ -37,11 +38,49 @@ sub startup {
 		push @{$self->static->paths}, $config->get("pubdir");
 	}
 
+	$self->hook(before_dispatch => sub {
+		my $c = shift;
+		my $vpr = $config->get('vid_prefix');
+		my $media = "media-src 'self'";
+		my $url = Mojo::URL->new($vpr);
+		if(defined($url->host)) {
+			$vpr = $url->host;
+			$media = "media-src $vpr;";
+		}
+		$c->res->headers->content_security_policy("default-src 'none'; connect-src 'self'; script-src 'self' 'unsafe-inline'; font-src 'self'; style-src 'self'; img-src 'self'; frame-ancestors 'none'; $media");
+	});
+
 	$self->helper(dbh => sub {
 		state $pg = Mojo::Pg->new->dsn($config->get('dbistring'));
 		return $pg->db->dbh;
 	});
-	
+	$self->helper(srconfig => sub {
+		return $config;
+	});
+
+	$self->helper(auth_scope => sub {
+		my $c = shift;
+		my $scope = shift;
+		$self->log->debug("checking if authorized for $scope");
+		if($c->session->{admin}) {
+			return 1;
+		} elsif($scope eq "api") {
+			return 1;
+		} elsif($scope eq "api/event") {
+			return 1;
+		} elsif($scope eq "api/talks") {
+			if(exists($c->session->{id})) {
+				return 1;
+			}
+		} elsif($scope eq "api/talks/detailed") {
+			if(exists($c->session->{id})) {
+				return 1;
+			}
+		}
+		$self->log->debug("not authorized for $scope");
+		return 0;
+	});
+
 	$self->helper(talk_update => sub {
 		my $c = shift;
 		my $talk = shift;
@@ -99,7 +138,11 @@ sub startup {
 		$rv = <GIT>;
 		close GIT;
 		if(!defined $rv) {
-			return $SReview::VERSION;
+			if(exists($ENV{GIT_DESCRIBE})) {
+				$rv = $ENV{GIT_DESCRIBE};
+			} else {
+				$rv = $SReview::VERSION;
+			}
 		}
 		chomp $rv;
 		return $rv;
@@ -144,6 +187,10 @@ sub startup {
 		}
 	});
 
+	$r->get('/r/:nonce')->to(controller => 'review', action => 'view', layout => 'default');
+	$r->post('/r/:nonce/update')->to(controller => 'review', layout => 'default', action => 'update');
+        $r->get('/r/:nonce/data')->to(controller => 'review', action => 'data');
+
 	$r->get('/review/:nonce' => sub {
 		my $c = shift;
 		my $stt = $c->dbh->prepare("SELECT state, name, id, extract(epoch from prelen) as prelen, extract(epoch from postlen) as postlen, extract(epoch from (endtime - starttime)) as length, speakers, starttime, endtime, slug, room, comments FROM talk_list WHERE nonce=?");
@@ -261,7 +308,10 @@ sub startup {
 					slug => $row->{slug},
 					room => $row->{room},
 					date => $row->{date},
+					event => $row->{event},
+					upstreamid => $row->{upstreamid},
 					year => $row->{year} });
+				chomp $video->{details_url};
 			}
 			$video->{video} = join('/',$outputdir, $row->{slug}) . "." . $formats{default}->exten;
 			push @$videos, $video;
@@ -274,9 +324,11 @@ sub startup {
 		my $c = shift;
 		my $st;
 		if($config->get("anonreviews")) {
-			$st = $c->dbh->prepare('SELECT nonce, name, speakers, room, starttime, endtime, state, progress FROM talk_list WHERE eventid = ? AND state IS NOT NULL ORDER BY state, progress, room, starttime');
+			$st = $c->dbh->prepare('SELECT nonce, name, speakers, room, starttime::timestamp, endtime::timestamp, state, progress FROM talk_list WHERE eventid = ? AND state IS NOT NULL ORDER BY state, progress, room, starttime');
+			$c->stash(autorefresh => 1);
 		} else {
-			$st = $c->dbh->prepare('SELECT name, speakers, room, starttime, endtime, state, progress FROM talk_list WHERE eventid = ? AND state IS NOT NULL ORDER BY state, progress, room, starttime');
+			$st = $c->dbh->prepare('SELECT name, speakers, room, starttime::timestamp, endtime::timestamp, state, progress FROM talk_list WHERE eventid = ? AND state IS NOT NULL ORDER BY state, progress, room, starttime');
+			$c->stash(autorefresh => 0);
 		}
 		my $tot = $c->dbh->prepare('SELECT state, count(*) FROM talks WHERE event = ? GROUP BY state ORDER BY state;');
 		my %expls;
@@ -289,6 +341,7 @@ sub startup {
 		$expls{'preview'} = 'Talk ready for review, waiting for reviewer';
 		$expls{'transcoding'} = 'High-quality transcodes running';
 		$expls{'uploading'} = 'Publishing results';
+		$expls{'announcing'} = 'Announcing completion of publication';
 		$expls{'done'} = 'Videos published, all done';
 		$expls{'broken'} = 'Review found problems, administrator required';
 		$expls{'ignored'} = 'Talk will not be/was not recorded, ignored for review';
@@ -305,7 +358,7 @@ sub startup {
 			foreach my $row(@$rows) {
 				my $nonce = shift @$row;
 				my $name = shift @$row;
-				push @$newrows, [ "<a href='/review/$nonce'>$name</a>", @$row ];
+				push @$newrows, [ "<a href='/r/$nonce'>$name</a>", @$row ];
 			}
 			$rows = $newrows;
 		}
@@ -356,31 +409,54 @@ sub startup {
 		return 1;
 	});
 
-	$vol->get('/list' => sub {
+	$vol->get('/list')->to('volunteer#list');
+
+	my $api = $r->under('/api/v1' => sub {
 		my $c = shift;
-		my @talks;
-		$c->dbh->begin_work;
-		my $already = $c->dbh->prepare("SELECT nonce, title, id, state FROM talks WHERE reviewer = ? AND state <= 'preview'");
-		my $new = $c->dbh->prepare("SELECT nonce, title, id, state FROM talks WHERE reviewer IS NULL AND state = 'preview'::talkstate LIMIT ? FOR UPDATE");
-		my $claim = $c->dbh->prepare("UPDATE talks SET reviewer = ? WHERE id = ?");
-		$already->execute($c->session->{id});
-		my $count = $already->rows;
-		if($count < 5) {
-			$new->execute(5 - $count);
+		if(!$c->auth_scope("api")) {
+			$c->res->code(403);
+			$self->log->debug("failed auth scope api");
+			$c->render(text => 'Unauthorized');
+			return 0;
 		}
-		for(my $i = 0; $i < $count; $i++) {
-			my $row = [ $already->fetchrow_array ];
-			push @talks, $row;
+		return 1;
+	});
+
+	my $event_api = $api->under('/events' => sub {
+		my $c = shift;
+		if(!$c->auth_scope("api/event")) {
+			$c->res->code(403);
+			$self->log->debug("failed auth scope event");
+			$c->render(text => 'Unauthorized');
+			return 0;
 		}
-		for(my $i = 0; $i < $new->rows; $i++) {
-			my $row = [ $new->fetchrow_array ];
-			$claim->execute($c->session->{id}, $row->[2]);
-			push @talks, $row;
+		return 1;
+	});
+
+	$event_api->post('/create')->to(controller => 'event', action => 'create');
+	$event_api->get('/by-title/:title')->to(controller => 'event', action => 'by_title');
+	$event_api->get('/by-id/:id')->to(controller => 'event', action => 'by_id');
+	$event_api->post('/update/:id')->to(controller => 'event', action => 'update');
+	$event_api->get('/list')->to(controller => 'event', action => 'list');
+	$event_api->delete('/delete/:id')->to(controller => 'event', action => 'delete');
+
+	my $talk_api = $api->under('/event/:event/talks' => sub {
+		my $c = shift;
+		if(!$c->auth_scope("api/talks")) {
+			$c->res->code(403);
+			$c->render(text => 'Unauthorized');
+			return 0;
 		}
-		$c->stash(talks => \@talks);
-		$c->stash(layout => 'admin');
-		$c->dbh->commit;
-	} => 'volunteer/list');
+		return 1;
+	});
+
+	$talk_api->post('/create')->to(controller => 'talk', action => 'create');
+	$talk_api->get('/by-title/:title')->to(controller => 'talk', action => 'by_title');
+	$talk_api->get('/by-id/:id')->to(controller => 'talk', action => 'by_id');
+	$talk_api->get('/by-nonce/:nonce')->to(controller => 'talk', action => 'by_nonce');
+	$talk_api->get('/list')->to(controller => 'talk', action => 'list');
+	$talk_api->post('/update')->to(controller => 'talk', action => 'update');
+	$talk_api->delete('/delete')->to(controller => 'talk', action => 'delete');
 
 	my $admin = $r->under('/admin' => sub {
 		my $c = shift;
@@ -402,38 +478,7 @@ sub startup {
 	$admin->any('/schedule/talk/')->to(controller => 'schedule', action => 'mod_talk');
 	$admin->any('/schedule/')->to(controller => 'schedule', action => 'index');
 
-	$admin->get('/' => sub {
-		my $c = shift;
-		my $st;
-		my $talks = ();
-		my $room;
-		my $lastroom = '';
-
-		if(defined($c->session->{room})) {
-			$st = $c->dbh->prepare('SELECT id, room, name, starttime, speakers, state FROM talk_list WHERE eventid = ? AND roomid = ? ORDER BY starttime');
-			$st->execute($c->eventid, $c->session->{room});
-		} else {
-			$st = $c->dbh->prepare('SELECT id, room, name, starttime, speakers, state FROM talk_list WHERE eventid = ? ORDER BY room, starttime');
-			$st->execute($c->eventid);
-		}
-		while(my $row = $st->fetchrow_hashref("NAME_lc")) {
-			if ($row->{'room'} ne $lastroom) {
-				if(defined($room)) {
-					push @$talks, c($lastroom => $room);
-				}
-				$room = [];
-			}
-			$lastroom = $row->{'room'};
-			next unless defined($row->{id});
-			push @$room, [$row->{'starttime'} . ': ' . $row->{'name'} . ' by ' . $row->{'speakers'} . ' (' . $row->{'state'} . ')' => $row->{'id'}];
-		}
-		if(defined($room)) {
-			push @$talks, c($lastroom => $room);
-		}
-		$c->stash(email => $c->session->{email});
-		$c->stash(talks => $talks);
-		$c->render;
-	} => 'admin/main');
+	$admin->get('/')->to('admin#main');
 
 	$admin->get('/logout' => sub {
 		my $c = shift;
@@ -514,7 +559,7 @@ sub startup {
 
 	$admin->get('/brokens' => sub {
 		my $c = shift;
-		my $st = $c->dbh->prepare("SELECT talks.id, title, speakeremail(talks.id), tracks.email, comments, state FROM talks JOIN tracks ON talks.track = tracks.id WHERE state>='broken' ORDER BY state,id");
+		my $st = $c->dbh->prepare("SELECT talks.id, title, speakeremail(talks.id), tracks.email, comments, state, nonce FROM talks JOIN tracks ON talks.track = tracks.id WHERE state>='broken' ORDER BY state,id");
 		my $tst = $c->dbh->prepare("SELECT rooms.altname, count(talks.id) FROM talks JOIN rooms ON talks.room = rooms.id WHERE talks.state='broken' GROUP BY rooms.altname");
 		my $rows = [];
 		$st->execute;
@@ -524,7 +569,8 @@ sub startup {
 		$c->stash(tottitrow => [ 'Room', 'Count' ]);
 		my $pgrows = $st->fetchall_arrayref;
 		foreach my $row(@{$pgrows}) {
-			push @$row, "<a href='/admin/talk?talk=" . $row->[0] . "'>review</a>";
+                        my $nonce = pop @$row;
+			push @$row, "<a href='/r/$nonce'>review</a>";
 			push @$rows, $row;
 		}
 		$c->stash(rows => $rows);
@@ -532,6 +578,7 @@ sub startup {
 		$c->stash(header => 'Broken talks');
 		$c->stash(layout => 'admin');
 		$c->stash(totals => undef);
+		$c->stash(autorefresh => 0);
 		$c->render(template => 'table');
 	} => 'broken_table');
 
